@@ -24,7 +24,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: OpenSSLCryptoKeyRSA.cpp 1819347 2017-12-27 18:05:51Z scantor $
+ * $Id: OpenSSLCryptoKeyRSA.cpp 1843562 2018-10-11 15:13:40Z scantor $
  *
  */
 
@@ -449,6 +449,12 @@ bool OpenSSLCryptoKeyRSA::verifySHA1PKCS1Base64Signature(
             "OpenSSL:RSA - Attempt to validate signature with empty key");
     }
 
+    XSECCryptoKey::KeyType keyType = getKeyType();
+    if (keyType != KEY_RSA_PAIR && keyType != KEY_RSA_PUBLIC) {
+        throw XSECCryptoException(XSECCryptoException::RSAError,
+            "OpenSSL:RSA - Attempt to validate signature without public key");
+    }
+
     char* cleanedBase64Signature;
     unsigned int cleanedBase64SignatureLen = 0;
 
@@ -568,6 +574,12 @@ unsigned int OpenSSLCryptoKeyRSA::signSHA1PKCS1Base64Signature(
             "OpenSSL:RSA - Attempt to sign data with empty key");
     }
 
+    KeyType keyType = getKeyType();
+    if (keyType != KEY_RSA_PAIR && keyType != KEY_RSA_PRIVATE) {
+        throw XSECCryptoException(XSECCryptoException::RSAError,
+            "OpenSSL:RSA - Attempt to sign data without private key");
+    }
+
     // Build the buffer to be encrypted by prepending the SHA1 OID to the hash
 
     unsigned char* encryptBuf;
